==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/panel/lxqt-panel_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>Bővítmény hozzáadás</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>Keresés:</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="98"/>
        <source>Add Widget</source>
        <translation>Elem hozzáadás</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="105"/>
        <source>Close</source>
        <translation>Bezár</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>(egy időben csak egy futhat)</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>Panelbeállítás</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="38"/>
        <source>Panel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="42"/>
        <source>Widgets</source>
        <translation>Elemek</translation>
    </message>
</context>
<context>
    <name>ConfigPanelWidget</name>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="20"/>
        <source>Configure panel</source>
        <translation>Panelbeállítás</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="44"/>
        <source>Size</source>
        <translation>Méret</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;Negatív pixel érték azt jelöli, hogy mennyivel rövidebb a panel a képernyőnél.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;Például -100px érték esetén az 1000px széles képernyőnél a panel hossza 900px.&lt;/i&gt;&lt;/p</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="81"/>
        <source>Size:</source>
        <translation>Méret:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="88"/>
        <source>Length:</source>
        <translation>Hossz:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="96"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="101"/>
        <source>px</source>
        <translation>pixel</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="109"/>
        <location filename="../../../config/configpanelwidget.ui" line="153"/>
        <source> px</source>
        <translation> pixel</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="166"/>
        <source>Icon size:</source>
        <translation>Ikonméret:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="173"/>
        <source>Rows count:</source>
        <translation>Sorszámláló:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation>Igazítás &amp;&amp; helyzet</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="224"/>
        <location filename="../../../config/configpanelwidget.ui" line="250"/>
        <source>Zero means no animation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="227"/>
        <source> ms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="240"/>
        <source>Position:</source>
        <translation>Helyzet:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="253"/>
        <source>Animation duration:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="260"/>
        <source>Alignment:</source>
        <translation>Igazítás:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="284"/>
        <location filename="../../../config/configpanelwidget.cpp" line="195"/>
        <source>Left</source>
        <translation>Balra</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="289"/>
        <location filename="../../../config/configpanelwidget.cpp" line="196"/>
        <location filename="../../../config/configpanelwidget.cpp" line="202"/>
        <source>Center</source>
        <translation>Középre</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="294"/>
        <location filename="../../../config/configpanelwidget.cpp" line="197"/>
        <source>Right</source>
        <translation>Jobbra</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="214"/>
        <source>Auto-hide</source>
        <translation>Automata elrejtés</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="314"/>
        <source>Custom styling</source>
        <translation>Egyéni stílus</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="335"/>
        <source>Font color:</source>
        <translation>Betűszín:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="375"/>
        <source>Background color:</source>
        <translation>Háttérszín:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="414"/>
        <source>Background opacity:</source>
        <translation>Háttér áttetszőség:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="446"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation>&lt;small&gt;Paneláttetszőséghez kompozitálás kell.&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="474"/>
        <source>Background image:</source>
        <translation>Háttér kép:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="161"/>
        <source>Top of desktop</source>
        <translation>Az asztal tetejére</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="162"/>
        <source>Left of desktop</source>
        <translation>Az asztal bal oldalára</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="163"/>
        <source>Right of desktop</source>
        <translation>Az asztal jobb oldalára</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="164"/>
        <source>Bottom of desktop</source>
        <translation>Az asztal aljára</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="173"/>
        <source>Top of desktop %1</source>
        <translation>A(z) %1. asztal tetejére</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="174"/>
        <source>Left of desktop %1</source>
        <translation>A(z) %1. asztal bal oldalára</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="175"/>
        <source>Right of desktop %1</source>
        <translation>A(z) %1. asztal jobb oldalára</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="176"/>
        <source>Bottom of desktop %1</source>
        <translation>A(z) %1. asztal aljára</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="201"/>
        <source>Top</source>
        <translation>Fenn</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="203"/>
        <source>Bottom</source>
        <translation>Lenn</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="360"/>
        <location filename="../../../config/configpanelwidget.cpp" line="376"/>
        <source>Pick color</source>
        <translation>Színválasztás</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="394"/>
        <source>Pick image</source>
        <translation>Képválasztás</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="394"/>
        <source>Images (*.png *.gif *.jpg)</source>
        <translation>Képek (*.png *.gif *.jpg)</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>Bővítménybeállítás</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>Megjegyzés: ezek a változtatások maradandóak.</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>Föl</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="115"/>
        <location filename="../../../config/configpluginswidget.ui" line="129"/>
        <location filename="../../../config/configpluginswidget.ui" line="150"/>
        <location filename="../../../config/configpluginswidget.ui" line="164"/>
        <location filename="../../../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>Le</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>Hozzáadás</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>Beállítás</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1012"/>
        <location filename="../../../lxqtpanel.cpp" line="1036"/>
        <source>Panel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1039"/>
        <source>Configure Panel</source>
        <translation>Panelbeállítás</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1044"/>
        <source>Manage Widgets</source>
        <translation>Bővítménykezelés</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1050"/>
        <source>Add New Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1062"/>
        <source>Lock This Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1200"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Panel</source>
        <translation type="vanished">Panel hozzáadás</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1057"/>
        <location filename="../../../lxqtpanel.cpp" line="1199"/>
        <source>Remove Panel</source>
        <translation>Panel törlés</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../../plugin.cpp" line="385"/>
        <source>Configure &quot;%1&quot;</source>
        <translation>&quot;%1&quot; beállítása</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="390"/>
        <source>Move &quot;%1&quot;</source>
        <translation>&quot;%1&quot; mozgatása</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="398"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>&quot;%1&quot; törlése</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="91"/>
        <source>Use alternate configuration file.</source>
        <translation>Egyéni beállítófájl használata.</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="92"/>
        <source>Configuration file</source>
        <translation>Beállítófájl</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/panel/lxqt-panel_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>Bővítmény hozzáadás</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>Keresés:</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="98"/>
        <source>Add Widget</source>
        <translation>Elem hozzáadás</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="105"/>
        <source>Close</source>
        <translation>Bezár</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>(egy időben csak egy futhat)</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>Panelbeállítás</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="38"/>
        <source>Panel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="42"/>
        <source>Widgets</source>
        <translation>Elemek</translation>
    </message>
</context>
<context>
    <name>ConfigPanelWidget</name>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="20"/>
        <source>Configure panel</source>
        <translation>Panelbeállítás</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="44"/>
        <source>Size</source>
        <translation>Méret</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;Negatív pixel érték azt jelöli, hogy mennyivel rövidebb a panel a képernyőnél.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;Például -100px érték esetén az 1000px széles képernyőnél a panel hossza 900px.&lt;/i&gt;&lt;/p</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="81"/>
        <source>Size:</source>
        <translation>Méret:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="88"/>
        <source>Length:</source>
        <translation>Hossz:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="96"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="101"/>
        <source>px</source>
        <translation>pixel</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="109"/>
        <location filename="../../../config/configpanelwidget.ui" line="153"/>
        <source> px</source>
        <translation> pixel</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="166"/>
        <source>Icon size:</source>
        <translation>Ikonméret:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="173"/>
        <source>Rows count:</source>
        <translation>Sorszámláló:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation>Igazítás &amp;&amp; helyzet</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="250"/>
        <source>A&amp;uto-hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="262"/>
        <location filename="../../../config/configpanelwidget.ui" line="285"/>
        <source>Zero means no animation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="288"/>
        <location filename="../../../config/configpanelwidget.ui" line="314"/>
        <source> ms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="301"/>
        <location filename="../../../config/configpanelwidget.ui" line="311"/>
        <source>Zero means no delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="304"/>
        <source>Show with delay:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="330"/>
        <source>Don&apos;t allow maximized windows go under the panel window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="333"/>
        <source>Reserve space on display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="237"/>
        <source>Position:</source>
        <translation>Helyzet:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="265"/>
        <source>Animation duration:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="208"/>
        <source>Alignment:</source>
        <translation>Igazítás:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="219"/>
        <location filename="../../../config/configpanelwidget.cpp" line="202"/>
        <source>Left</source>
        <translation>Balra</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="224"/>
        <location filename="../../../config/configpanelwidget.cpp" line="203"/>
        <location filename="../../../config/configpanelwidget.cpp" line="209"/>
        <source>Center</source>
        <translation>Középre</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="229"/>
        <location filename="../../../config/configpanelwidget.cpp" line="204"/>
        <source>Right</source>
        <translation>Jobbra</translation>
    </message>
    <message>
        <source>Auto-hide</source>
        <translation type="vanished">Automata elrejtés</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="349"/>
        <source>Custom styling</source>
        <translation>Egyéni stílus</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="370"/>
        <source>Font color:</source>
        <translation>Betűszín:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="410"/>
        <source>Background color:</source>
        <translation>Háttérszín:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="449"/>
        <source>Background opacity:</source>
        <translation>Háttér áttetszőség:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="481"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation>&lt;small&gt;Paneláttetszőséghez kompozitálás kell.&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="509"/>
        <source>Background image:</source>
        <translation>Háttér kép:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="168"/>
        <source>Top of desktop</source>
        <translation>Az asztal tetejére</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="169"/>
        <source>Left of desktop</source>
        <translation>Az asztal bal oldalára</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="170"/>
        <source>Right of desktop</source>
        <translation>Az asztal jobb oldalára</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="171"/>
        <source>Bottom of desktop</source>
        <translation>Az asztal aljára</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="180"/>
        <source>Top of desktop %1</source>
        <translation>A(z) %1. asztal tetejére</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="181"/>
        <source>Left of desktop %1</source>
        <translation>A(z) %1. asztal bal oldalára</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="182"/>
        <source>Right of desktop %1</source>
        <translation>A(z) %1. asztal jobb oldalára</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="183"/>
        <source>Bottom of desktop %1</source>
        <translation>A(z) %1. asztal aljára</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="208"/>
        <source>Top</source>
        <translation>Fenn</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="210"/>
        <source>Bottom</source>
        <translation>Lenn</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="368"/>
        <location filename="../../../config/configpanelwidget.cpp" line="384"/>
        <source>Pick color</source>
        <translation>Színválasztás</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="402"/>
        <source>Pick image</source>
        <translation>Képválasztás</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="402"/>
        <source>Images (*.png *.gif *.jpg)</source>
        <translation>Képek (*.png *.gif *.jpg)</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>Bővítménybeállítás</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>Megjegyzés: ezek a változtatások maradandóak.</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>Föl</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="115"/>
        <location filename="../../../config/configpluginswidget.ui" line="129"/>
        <location filename="../../../config/configpluginswidget.ui" line="150"/>
        <location filename="../../../config/configpluginswidget.ui" line="164"/>
        <location filename="../../../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>Le</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>Hozzáadás</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>Beállítás</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1066"/>
        <location filename="../../../lxqtpanel.cpp" line="1091"/>
        <source>Panel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1094"/>
        <source>Configure Panel</source>
        <translation>Panelbeállítás</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1099"/>
        <source>Manage Widgets</source>
        <translation>Bővítménykezelés</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1105"/>
        <source>Add New Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1112"/>
        <source>Remove Panel</source>
        <comment>Menu Item</comment>
        <translation type="unfinished">Panel törlés</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1117"/>
        <source>Lock This Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1259"/>
        <source>Remove Panel</source>
        <comment>Dialog Title</comment>
        <translation type="unfinished">Panel törlés</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1260"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Panel</source>
        <translation type="vanished">Panel hozzáadás</translation>
    </message>
    <message>
        <source>Remove Panel</source>
        <translation type="vanished">Panel törlés</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../../plugin.cpp" line="416"/>
        <source>Configure &quot;%1&quot;</source>
        <translation>&quot;%1&quot; beállítása</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="421"/>
        <source>Move &quot;%1&quot;</source>
        <translation>&quot;%1&quot; mozgatása</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="429"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>&quot;%1&quot; törlése</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="95"/>
        <source>Use alternate configuration file.</source>
        <translation>Egyéni beállítófájl használata.</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="96"/>
        <source>Configuration file</source>
        <translation>Beállítófájl</translation>
    </message>
</context>
</TS>
